/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * This code was generated by https://code.google.com/p/google-apis-client-generator/
 * (build: 2013-06-20 19:08:55 UTC)
 * on 2013-06-22 at 06:09:16 UTC 
 * Modify at your own risk.
 */

package com.google.api.services.reseller;

/**
 * Service definition for Reseller (v1).
 *
 * <p>
 * Lets you create and manage your customers and their subscriptions.
 * </p>
 *
 * <p>
 * For more information about this service, see the
 * <a href="https://developers.google.com/google-apps/reseller/" target="_blank">API Documentation</a>
 * </p>
 *
 * <p>
 * This service uses {@link ResellerRequestInitializer} to initialize global parameters via its
 * {@link Builder}.
 * </p>
 *
 * @since 1.3
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public class Reseller extends com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient {

  // Note: Leave this static initializer at the top of the file.
  static {
    com.google.api.client.util.Preconditions.checkState(
        com.google.api.client.googleapis.GoogleUtils.MAJOR_VERSION == 1 &&
        com.google.api.client.googleapis.GoogleUtils.MINOR_VERSION >= 15,
        "You are currently running with version %s of google-api-client. " +
        "You need at least version 1.15 of google-api-client to run version " +
        "1.15.0-rc of the Enterprise Apps Reseller API library.", com.google.api.client.googleapis.GoogleUtils.VERSION);
  }

  /**
   * The default encoded root URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_ROOT_URL = "https://www.googleapis.com/";

  /**
   * The default encoded service path of the service. This is determined when the library is
   * generated and normally should not be changed.
   *
   * @since 1.7
   */
  public static final String DEFAULT_SERVICE_PATH = "apps/reseller/v1/";

  /**
   * The default encoded base URL of the service. This is determined when the library is generated
   * and normally should not be changed.
   */
  public static final String DEFAULT_BASE_URL = DEFAULT_ROOT_URL + DEFAULT_SERVICE_PATH;

  /**
   * Constructor.
   *
   * <p>
   * Use {@link Builder} if you need to specify any of the optional parameters.
   * </p>
   *
   * @param transport HTTP transport, which should normally be:
   *        <ul>
   *        <li>Google App Engine:
   *        {@code com.google.api.client.extensions.appengine.http.UrlFetchTransport}</li>
   *        <li>Android: {@code newCompatibleTransport} from
   *        {@code com.google.api.client.extensions.android.http.AndroidHttp}</li>
   *        <li>Java: {@link com.google.api.client.googleapis.javanet.GoogleNetHttpTransport#newTrustedTransport()}
   *        </li>
   *        </ul>
   * @param jsonFactory JSON factory, which may be:
   *        <ul>
   *        <li>Jackson: {@code com.google.api.client.json.jackson2.JacksonFactory}</li>
   *        <li>Google GSON: {@code com.google.api.client.json.gson.GsonFactory}</li>
   *        <li>Android Honeycomb or higher:
   *        {@code com.google.api.client.extensions.android.json.AndroidJsonFactory}</li>
   *        </ul>
   * @param httpRequestInitializer HTTP request initializer or {@code null} for none
   * @since 1.7
   */
  public Reseller(com.google.api.client.http.HttpTransport transport, com.google.api.client.json.JsonFactory jsonFactory,
      com.google.api.client.http.HttpRequestInitializer httpRequestInitializer) {
    this(new Builder(transport, jsonFactory, httpRequestInitializer));
  }

  /**
   * @param builder builder
   */
  Reseller(Builder builder) {
    super(builder);
  }

  @Override
  protected void initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest<?> httpClientRequest) throws java.io.IOException {
    super.initialize(httpClientRequest);
  }

  /**
   * An accessor for creating requests from the Customers collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Reseller reseller = new Reseller(...);}
   *   {@code Reseller.Customers.List request = reseller.customers().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Customers customers() {
    return new Customers();
  }

  /**
   * The "customers" collection of methods.
   */
  public class Customers {

    /**
     * Gets a customer resource if one exists and is owned by the reseller.
     *
     * Create a request for the method "customers.get".
     *
     * This request holds the parameters needed by the the reseller server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param customerId Id of the Customer
     * @return the request
     */
    public Get get(java.lang.String customerId) throws java.io.IOException {
      Get result = new Get(customerId);
      initialize(result);
      return result;
    }

    public class Get extends ResellerRequest<com.google.api.services.reseller.model.Customer> {

      private static final String REST_PATH = "customers/{customerId}";

      /**
       * Gets a customer resource if one exists and is owned by the reseller.
       *
       * Create a request for the method "customers.get".
       *
       * This request holds the parameters needed by the the reseller server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
       * {@link Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param customerId Id of the Customer
       * @since 1.13
       */
      protected Get(java.lang.String customerId) {
        super(Reseller.this, "GET", REST_PATH, null, com.google.api.services.reseller.model.Customer.class);
        this.customerId = com.google.api.client.util.Preconditions.checkNotNull(customerId, "Required parameter customerId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(java.lang.String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(java.lang.String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(java.lang.String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(java.lang.String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(java.lang.String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(java.lang.String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** Id of the Customer */
      @com.google.api.client.util.Key
      private java.lang.String customerId;

      /** Id of the Customer
       */
      public java.lang.String getCustomerId() {
        return customerId;
      }

      /** Id of the Customer */
      public Get setCustomerId(java.lang.String customerId) {
        this.customerId = customerId;
        return this;
      }

      @Override
      public Get set(String parameterName, Object value) {
        return (Get) super.set(parameterName, value);
      }
    }
    /**
     * Creates a customer resource if one does not already exist.
     *
     * Create a request for the method "customers.insert".
     *
     * This request holds the parameters needed by the the reseller server.  After setting any optional
     * parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * @param content the {@link com.google.api.services.reseller.model.Customer}
     * @return the request
     */
    public Insert insert(com.google.api.services.reseller.model.Customer content) throws java.io.IOException {
      Insert result = new Insert(content);
      initialize(result);
      return result;
    }

    public class Insert extends ResellerRequest<com.google.api.services.reseller.model.Customer> {

      private static final String REST_PATH = "customers";

      /**
       * Creates a customer resource if one does not already exist.
       *
       * Create a request for the method "customers.insert".
       *
       * This request holds the parameters needed by the the reseller server.  After setting any
       * optional parameters, call the {@link Insert#execute()} method to invoke the remote operation.
       * <p> {@link
       * Insert#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
       * be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param content the {@link com.google.api.services.reseller.model.Customer}
       * @since 1.13
       */
      protected Insert(com.google.api.services.reseller.model.Customer content) {
        super(Reseller.this, "POST", REST_PATH, content, com.google.api.services.reseller.model.Customer.class);
      }

      @Override
      public Insert setAlt(java.lang.String alt) {
        return (Insert) super.setAlt(alt);
      }

      @Override
      public Insert setFields(java.lang.String fields) {
        return (Insert) super.setFields(fields);
      }

      @Override
      public Insert setKey(java.lang.String key) {
        return (Insert) super.setKey(key);
      }

      @Override
      public Insert setOauthToken(java.lang.String oauthToken) {
        return (Insert) super.setOauthToken(oauthToken);
      }

      @Override
      public Insert setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Insert) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Insert setQuotaUser(java.lang.String quotaUser) {
        return (Insert) super.setQuotaUser(quotaUser);
      }

      @Override
      public Insert setUserIp(java.lang.String userIp) {
        return (Insert) super.setUserIp(userIp);
      }

      /**
       * An auth token needed for inserting a customer for which domain already exists. Can be
       * generated at https://www.google.com/a/cpanel//TransferToken. Optional.
       */
      @com.google.api.client.util.Key
      private java.lang.String customerAuthToken;

      /** An auth token needed for inserting a customer for which domain already exists. Can be generated at
     https://www.google.com/a/cpanel//TransferToken. Optional.
       */
      public java.lang.String getCustomerAuthToken() {
        return customerAuthToken;
      }

      /**
       * An auth token needed for inserting a customer for which domain already exists. Can be
       * generated at https://www.google.com/a/cpanel//TransferToken. Optional.
       */
      public Insert setCustomerAuthToken(java.lang.String customerAuthToken) {
        this.customerAuthToken = customerAuthToken;
        return this;
      }

      @Override
      public Insert set(String parameterName, Object value) {
        return (Insert) super.set(parameterName, value);
      }
    }
    /**
     * Update a customer resource if one it exists and is owned by the reseller. This method supports
     * patch semantics.
     *
     * Create a request for the method "customers.patch".
     *
     * This request holds the parameters needed by the the reseller server.  After setting any optional
     * parameters, call the {@link Patch#execute()} method to invoke the remote operation.
     *
     * @param customerId Id of the Customer
     * @param content the {@link com.google.api.services.reseller.model.Customer}
     * @return the request
     */
    public Patch patch(java.lang.String customerId, com.google.api.services.reseller.model.Customer content) throws java.io.IOException {
      Patch result = new Patch(customerId, content);
      initialize(result);
      return result;
    }

    public class Patch extends ResellerRequest<com.google.api.services.reseller.model.Customer> {

      private static final String REST_PATH = "customers/{customerId}";

      /**
       * Update a customer resource if one it exists and is owned by the reseller. This method supports
       * patch semantics.
       *
       * Create a request for the method "customers.patch".
       *
       * This request holds the parameters needed by the the reseller server.  After setting any
       * optional parameters, call the {@link Patch#execute()} method to invoke the remote operation.
       * <p> {@link
       * Patch#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
       * be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param customerId Id of the Customer
       * @param content the {@link com.google.api.services.reseller.model.Customer}
       * @since 1.13
       */
      protected Patch(java.lang.String customerId, com.google.api.services.reseller.model.Customer content) {
        super(Reseller.this, "PATCH", REST_PATH, content, com.google.api.services.reseller.model.Customer.class);
        this.customerId = com.google.api.client.util.Preconditions.checkNotNull(customerId, "Required parameter customerId must be specified.");
      }

      @Override
      public Patch setAlt(java.lang.String alt) {
        return (Patch) super.setAlt(alt);
      }

      @Override
      public Patch setFields(java.lang.String fields) {
        return (Patch) super.setFields(fields);
      }

      @Override
      public Patch setKey(java.lang.String key) {
        return (Patch) super.setKey(key);
      }

      @Override
      public Patch setOauthToken(java.lang.String oauthToken) {
        return (Patch) super.setOauthToken(oauthToken);
      }

      @Override
      public Patch setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Patch) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Patch setQuotaUser(java.lang.String quotaUser) {
        return (Patch) super.setQuotaUser(quotaUser);
      }

      @Override
      public Patch setUserIp(java.lang.String userIp) {
        return (Patch) super.setUserIp(userIp);
      }

      /** Id of the Customer */
      @com.google.api.client.util.Key
      private java.lang.String customerId;

      /** Id of the Customer
       */
      public java.lang.String getCustomerId() {
        return customerId;
      }

      /** Id of the Customer */
      public Patch setCustomerId(java.lang.String customerId) {
        this.customerId = customerId;
        return this;
      }

      @Override
      public Patch set(String parameterName, Object value) {
        return (Patch) super.set(parameterName, value);
      }
    }
    /**
     * Update a customer resource if one it exists and is owned by the reseller.
     *
     * Create a request for the method "customers.update".
     *
     * This request holds the parameters needed by the the reseller server.  After setting any optional
     * parameters, call the {@link Update#execute()} method to invoke the remote operation.
     *
     * @param customerId Id of the Customer
     * @param content the {@link com.google.api.services.reseller.model.Customer}
     * @return the request
     */
    public Update update(java.lang.String customerId, com.google.api.services.reseller.model.Customer content) throws java.io.IOException {
      Update result = new Update(customerId, content);
      initialize(result);
      return result;
    }

    public class Update extends ResellerRequest<com.google.api.services.reseller.model.Customer> {

      private static final String REST_PATH = "customers/{customerId}";

      /**
       * Update a customer resource if one it exists and is owned by the reseller.
       *
       * Create a request for the method "customers.update".
       *
       * This request holds the parameters needed by the the reseller server.  After setting any
       * optional parameters, call the {@link Update#execute()} method to invoke the remote operation.
       * <p> {@link
       * Update#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
       * be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param customerId Id of the Customer
       * @param content the {@link com.google.api.services.reseller.model.Customer}
       * @since 1.13
       */
      protected Update(java.lang.String customerId, com.google.api.services.reseller.model.Customer content) {
        super(Reseller.this, "PUT", REST_PATH, content, com.google.api.services.reseller.model.Customer.class);
        this.customerId = com.google.api.client.util.Preconditions.checkNotNull(customerId, "Required parameter customerId must be specified.");
      }

      @Override
      public Update setAlt(java.lang.String alt) {
        return (Update) super.setAlt(alt);
      }

      @Override
      public Update setFields(java.lang.String fields) {
        return (Update) super.setFields(fields);
      }

      @Override
      public Update setKey(java.lang.String key) {
        return (Update) super.setKey(key);
      }

      @Override
      public Update setOauthToken(java.lang.String oauthToken) {
        return (Update) super.setOauthToken(oauthToken);
      }

      @Override
      public Update setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Update) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Update setQuotaUser(java.lang.String quotaUser) {
        return (Update) super.setQuotaUser(quotaUser);
      }

      @Override
      public Update setUserIp(java.lang.String userIp) {
        return (Update) super.setUserIp(userIp);
      }

      /** Id of the Customer */
      @com.google.api.client.util.Key
      private java.lang.String customerId;

      /** Id of the Customer
       */
      public java.lang.String getCustomerId() {
        return customerId;
      }

      /** Id of the Customer */
      public Update setCustomerId(java.lang.String customerId) {
        this.customerId = customerId;
        return this;
      }

      @Override
      public Update set(String parameterName, Object value) {
        return (Update) super.set(parameterName, value);
      }
    }

  }

  /**
   * An accessor for creating requests from the Subscriptions collection.
   *
   * <p>The typical use is:</p>
   * <pre>
   *   {@code Reseller reseller = new Reseller(...);}
   *   {@code Reseller.Subscriptions.List request = reseller.subscriptions().list(parameters ...)}
   * </pre>
   *
   * @return the resource collection
   */
  public Subscriptions subscriptions() {
    return new Subscriptions();
  }

  /**
   * The "subscriptions" collection of methods.
   */
  public class Subscriptions {

    /**
     * Changes the plan of a subscription
     *
     * Create a request for the method "subscriptions.changePlan".
     *
     * This request holds the parameters needed by the the reseller server.  After setting any optional
     * parameters, call the {@link ChangePlan#execute()} method to invoke the remote operation.
     *
     * @param customerId Id of the Customer
     * @param subscriptionId Id of the subscription, which is unique for a customer
     * @param content the {@link com.google.api.services.reseller.model.ChangePlanRequest}
     * @return the request
     */
    public ChangePlan changePlan(java.lang.String customerId, java.lang.String subscriptionId, com.google.api.services.reseller.model.ChangePlanRequest content) throws java.io.IOException {
      ChangePlan result = new ChangePlan(customerId, subscriptionId, content);
      initialize(result);
      return result;
    }

    public class ChangePlan extends ResellerRequest<com.google.api.services.reseller.model.Subscription> {

      private static final String REST_PATH = "customers/{customerId}/subscriptions/{subscriptionId}/changePlan";

      /**
       * Changes the plan of a subscription
       *
       * Create a request for the method "subscriptions.changePlan".
       *
       * This request holds the parameters needed by the the reseller server.  After setting any
       * optional parameters, call the {@link ChangePlan#execute()} method to invoke the remote
       * operation. <p> {@link
       * ChangePlan#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param customerId Id of the Customer
       * @param subscriptionId Id of the subscription, which is unique for a customer
       * @param content the {@link com.google.api.services.reseller.model.ChangePlanRequest}
       * @since 1.13
       */
      protected ChangePlan(java.lang.String customerId, java.lang.String subscriptionId, com.google.api.services.reseller.model.ChangePlanRequest content) {
        super(Reseller.this, "POST", REST_PATH, content, com.google.api.services.reseller.model.Subscription.class);
        this.customerId = com.google.api.client.util.Preconditions.checkNotNull(customerId, "Required parameter customerId must be specified.");
        this.subscriptionId = com.google.api.client.util.Preconditions.checkNotNull(subscriptionId, "Required parameter subscriptionId must be specified.");
      }

      @Override
      public ChangePlan setAlt(java.lang.String alt) {
        return (ChangePlan) super.setAlt(alt);
      }

      @Override
      public ChangePlan setFields(java.lang.String fields) {
        return (ChangePlan) super.setFields(fields);
      }

      @Override
      public ChangePlan setKey(java.lang.String key) {
        return (ChangePlan) super.setKey(key);
      }

      @Override
      public ChangePlan setOauthToken(java.lang.String oauthToken) {
        return (ChangePlan) super.setOauthToken(oauthToken);
      }

      @Override
      public ChangePlan setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (ChangePlan) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public ChangePlan setQuotaUser(java.lang.String quotaUser) {
        return (ChangePlan) super.setQuotaUser(quotaUser);
      }

      @Override
      public ChangePlan setUserIp(java.lang.String userIp) {
        return (ChangePlan) super.setUserIp(userIp);
      }

      /** Id of the Customer */
      @com.google.api.client.util.Key
      private java.lang.String customerId;

      /** Id of the Customer
       */
      public java.lang.String getCustomerId() {
        return customerId;
      }

      /** Id of the Customer */
      public ChangePlan setCustomerId(java.lang.String customerId) {
        this.customerId = customerId;
        return this;
      }

      /** Id of the subscription, which is unique for a customer */
      @com.google.api.client.util.Key
      private java.lang.String subscriptionId;

      /** Id of the subscription, which is unique for a customer
       */
      public java.lang.String getSubscriptionId() {
        return subscriptionId;
      }

      /** Id of the subscription, which is unique for a customer */
      public ChangePlan setSubscriptionId(java.lang.String subscriptionId) {
        this.subscriptionId = subscriptionId;
        return this;
      }

      @Override
      public ChangePlan set(String parameterName, Object value) {
        return (ChangePlan) super.set(parameterName, value);
      }
    }
    /**
     * Changes the renewal settings of a subscription
     *
     * Create a request for the method "subscriptions.changeRenewalSettings".
     *
     * This request holds the parameters needed by the the reseller server.  After setting any optional
     * parameters, call the {@link ChangeRenewalSettings#execute()} method to invoke the remote
     * operation.
     *
     * @param customerId Id of the Customer
     * @param subscriptionId Id of the subscription, which is unique for a customer
     * @param content the {@link com.google.api.services.reseller.model.RenewalSettings}
     * @return the request
     */
    public ChangeRenewalSettings changeRenewalSettings(java.lang.String customerId, java.lang.String subscriptionId, com.google.api.services.reseller.model.RenewalSettings content) throws java.io.IOException {
      ChangeRenewalSettings result = new ChangeRenewalSettings(customerId, subscriptionId, content);
      initialize(result);
      return result;
    }

    public class ChangeRenewalSettings extends ResellerRequest<com.google.api.services.reseller.model.Subscription> {

      private static final String REST_PATH = "customers/{customerId}/subscriptions/{subscriptionId}/changeRenewalSettings";

      /**
       * Changes the renewal settings of a subscription
       *
       * Create a request for the method "subscriptions.changeRenewalSettings".
       *
       * This request holds the parameters needed by the the reseller server.  After setting any
       * optional parameters, call the {@link ChangeRenewalSettings#execute()} method to invoke the
       * remote operation. <p> {@link ChangeRenewalSettings#initialize(com.google.api.client.googleapis.
       * services.AbstractGoogleClientRequest)} must be called to initialize this instance immediately
       * after invoking the constructor. </p>
       *
       * @param customerId Id of the Customer
       * @param subscriptionId Id of the subscription, which is unique for a customer
       * @param content the {@link com.google.api.services.reseller.model.RenewalSettings}
       * @since 1.13
       */
      protected ChangeRenewalSettings(java.lang.String customerId, java.lang.String subscriptionId, com.google.api.services.reseller.model.RenewalSettings content) {
        super(Reseller.this, "POST", REST_PATH, content, com.google.api.services.reseller.model.Subscription.class);
        this.customerId = com.google.api.client.util.Preconditions.checkNotNull(customerId, "Required parameter customerId must be specified.");
        this.subscriptionId = com.google.api.client.util.Preconditions.checkNotNull(subscriptionId, "Required parameter subscriptionId must be specified.");
      }

      @Override
      public ChangeRenewalSettings setAlt(java.lang.String alt) {
        return (ChangeRenewalSettings) super.setAlt(alt);
      }

      @Override
      public ChangeRenewalSettings setFields(java.lang.String fields) {
        return (ChangeRenewalSettings) super.setFields(fields);
      }

      @Override
      public ChangeRenewalSettings setKey(java.lang.String key) {
        return (ChangeRenewalSettings) super.setKey(key);
      }

      @Override
      public ChangeRenewalSettings setOauthToken(java.lang.String oauthToken) {
        return (ChangeRenewalSettings) super.setOauthToken(oauthToken);
      }

      @Override
      public ChangeRenewalSettings setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (ChangeRenewalSettings) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public ChangeRenewalSettings setQuotaUser(java.lang.String quotaUser) {
        return (ChangeRenewalSettings) super.setQuotaUser(quotaUser);
      }

      @Override
      public ChangeRenewalSettings setUserIp(java.lang.String userIp) {
        return (ChangeRenewalSettings) super.setUserIp(userIp);
      }

      /** Id of the Customer */
      @com.google.api.client.util.Key
      private java.lang.String customerId;

      /** Id of the Customer
       */
      public java.lang.String getCustomerId() {
        return customerId;
      }

      /** Id of the Customer */
      public ChangeRenewalSettings setCustomerId(java.lang.String customerId) {
        this.customerId = customerId;
        return this;
      }

      /** Id of the subscription, which is unique for a customer */
      @com.google.api.client.util.Key
      private java.lang.String subscriptionId;

      /** Id of the subscription, which is unique for a customer
       */
      public java.lang.String getSubscriptionId() {
        return subscriptionId;
      }

      /** Id of the subscription, which is unique for a customer */
      public ChangeRenewalSettings setSubscriptionId(java.lang.String subscriptionId) {
        this.subscriptionId = subscriptionId;
        return this;
      }

      @Override
      public ChangeRenewalSettings set(String parameterName, Object value) {
        return (ChangeRenewalSettings) super.set(parameterName, value);
      }
    }
    /**
     * Changes the seats configuration of a subscription
     *
     * Create a request for the method "subscriptions.changeSeats".
     *
     * This request holds the parameters needed by the the reseller server.  After setting any optional
     * parameters, call the {@link ChangeSeats#execute()} method to invoke the remote operation.
     *
     * @param customerId Id of the Customer
     * @param subscriptionId Id of the subscription, which is unique for a customer
     * @param content the {@link com.google.api.services.reseller.model.Seats}
     * @return the request
     */
    public ChangeSeats changeSeats(java.lang.String customerId, java.lang.String subscriptionId, com.google.api.services.reseller.model.Seats content) throws java.io.IOException {
      ChangeSeats result = new ChangeSeats(customerId, subscriptionId, content);
      initialize(result);
      return result;
    }

    public class ChangeSeats extends ResellerRequest<com.google.api.services.reseller.model.Subscription> {

      private static final String REST_PATH = "customers/{customerId}/subscriptions/{subscriptionId}/changeSeats";

      /**
       * Changes the seats configuration of a subscription
       *
       * Create a request for the method "subscriptions.changeSeats".
       *
       * This request holds the parameters needed by the the reseller server.  After setting any
       * optional parameters, call the {@link ChangeSeats#execute()} method to invoke the remote
       * operation. <p> {@link
       * ChangeSeats#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param customerId Id of the Customer
       * @param subscriptionId Id of the subscription, which is unique for a customer
       * @param content the {@link com.google.api.services.reseller.model.Seats}
       * @since 1.13
       */
      protected ChangeSeats(java.lang.String customerId, java.lang.String subscriptionId, com.google.api.services.reseller.model.Seats content) {
        super(Reseller.this, "POST", REST_PATH, content, com.google.api.services.reseller.model.Subscription.class);
        this.customerId = com.google.api.client.util.Preconditions.checkNotNull(customerId, "Required parameter customerId must be specified.");
        this.subscriptionId = com.google.api.client.util.Preconditions.checkNotNull(subscriptionId, "Required parameter subscriptionId must be specified.");
      }

      @Override
      public ChangeSeats setAlt(java.lang.String alt) {
        return (ChangeSeats) super.setAlt(alt);
      }

      @Override
      public ChangeSeats setFields(java.lang.String fields) {
        return (ChangeSeats) super.setFields(fields);
      }

      @Override
      public ChangeSeats setKey(java.lang.String key) {
        return (ChangeSeats) super.setKey(key);
      }

      @Override
      public ChangeSeats setOauthToken(java.lang.String oauthToken) {
        return (ChangeSeats) super.setOauthToken(oauthToken);
      }

      @Override
      public ChangeSeats setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (ChangeSeats) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public ChangeSeats setQuotaUser(java.lang.String quotaUser) {
        return (ChangeSeats) super.setQuotaUser(quotaUser);
      }

      @Override
      public ChangeSeats setUserIp(java.lang.String userIp) {
        return (ChangeSeats) super.setUserIp(userIp);
      }

      /** Id of the Customer */
      @com.google.api.client.util.Key
      private java.lang.String customerId;

      /** Id of the Customer
       */
      public java.lang.String getCustomerId() {
        return customerId;
      }

      /** Id of the Customer */
      public ChangeSeats setCustomerId(java.lang.String customerId) {
        this.customerId = customerId;
        return this;
      }

      /** Id of the subscription, which is unique for a customer */
      @com.google.api.client.util.Key
      private java.lang.String subscriptionId;

      /** Id of the subscription, which is unique for a customer
       */
      public java.lang.String getSubscriptionId() {
        return subscriptionId;
      }

      /** Id of the subscription, which is unique for a customer */
      public ChangeSeats setSubscriptionId(java.lang.String subscriptionId) {
        this.subscriptionId = subscriptionId;
        return this;
      }

      @Override
      public ChangeSeats set(String parameterName, Object value) {
        return (ChangeSeats) super.set(parameterName, value);
      }
    }
    /**
     * Cancels/Downgrades a subscription.
     *
     * Create a request for the method "subscriptions.delete".
     *
     * This request holds the parameters needed by the the reseller server.  After setting any optional
     * parameters, call the {@link Delete#execute()} method to invoke the remote operation.
     *
     * @param customerId Id of the Customer
     * @param subscriptionId Id of the subscription, which is unique for a customer
     * @param deletionType Whether the subscription is to be fully cancelled or downgraded
     * @return the request
     */
    public Delete delete(java.lang.String customerId, java.lang.String subscriptionId, java.lang.String deletionType) throws java.io.IOException {
      Delete result = new Delete(customerId, subscriptionId, deletionType);
      initialize(result);
      return result;
    }

    public class Delete extends ResellerRequest<Void> {

      private static final String REST_PATH = "customers/{customerId}/subscriptions/{subscriptionId}";

      /**
       * Cancels/Downgrades a subscription.
       *
       * Create a request for the method "subscriptions.delete".
       *
       * This request holds the parameters needed by the the reseller server.  After setting any
       * optional parameters, call the {@link Delete#execute()} method to invoke the remote operation.
       * <p> {@link
       * Delete#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
       * be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param customerId Id of the Customer
       * @param subscriptionId Id of the subscription, which is unique for a customer
       * @param deletionType Whether the subscription is to be fully cancelled or downgraded
       * @since 1.13
       */
      protected Delete(java.lang.String customerId, java.lang.String subscriptionId, java.lang.String deletionType) {
        super(Reseller.this, "DELETE", REST_PATH, null, Void.class);
        this.customerId = com.google.api.client.util.Preconditions.checkNotNull(customerId, "Required parameter customerId must be specified.");
        this.subscriptionId = com.google.api.client.util.Preconditions.checkNotNull(subscriptionId, "Required parameter subscriptionId must be specified.");
        this.deletionType = com.google.api.client.util.Preconditions.checkNotNull(deletionType, "Required parameter deletionType must be specified.");
      }

      @Override
      public Delete setAlt(java.lang.String alt) {
        return (Delete) super.setAlt(alt);
      }

      @Override
      public Delete setFields(java.lang.String fields) {
        return (Delete) super.setFields(fields);
      }

      @Override
      public Delete setKey(java.lang.String key) {
        return (Delete) super.setKey(key);
      }

      @Override
      public Delete setOauthToken(java.lang.String oauthToken) {
        return (Delete) super.setOauthToken(oauthToken);
      }

      @Override
      public Delete setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Delete) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Delete setQuotaUser(java.lang.String quotaUser) {
        return (Delete) super.setQuotaUser(quotaUser);
      }

      @Override
      public Delete setUserIp(java.lang.String userIp) {
        return (Delete) super.setUserIp(userIp);
      }

      /** Id of the Customer */
      @com.google.api.client.util.Key
      private java.lang.String customerId;

      /** Id of the Customer
       */
      public java.lang.String getCustomerId() {
        return customerId;
      }

      /** Id of the Customer */
      public Delete setCustomerId(java.lang.String customerId) {
        this.customerId = customerId;
        return this;
      }

      /** Id of the subscription, which is unique for a customer */
      @com.google.api.client.util.Key
      private java.lang.String subscriptionId;

      /** Id of the subscription, which is unique for a customer
       */
      public java.lang.String getSubscriptionId() {
        return subscriptionId;
      }

      /** Id of the subscription, which is unique for a customer */
      public Delete setSubscriptionId(java.lang.String subscriptionId) {
        this.subscriptionId = subscriptionId;
        return this;
      }

      /** Whether the subscription is to be fully cancelled or downgraded */
      @com.google.api.client.util.Key
      private java.lang.String deletionType;

      /** Whether the subscription is to be fully cancelled or downgraded
       */
      public java.lang.String getDeletionType() {
        return deletionType;
      }

      /** Whether the subscription is to be fully cancelled or downgraded */
      public Delete setDeletionType(java.lang.String deletionType) {
        this.deletionType = deletionType;
        return this;
      }

      @Override
      public Delete set(String parameterName, Object value) {
        return (Delete) super.set(parameterName, value);
      }
    }
    /**
     * Gets a subscription of the customer.
     *
     * Create a request for the method "subscriptions.get".
     *
     * This request holds the parameters needed by the the reseller server.  After setting any optional
     * parameters, call the {@link Get#execute()} method to invoke the remote operation.
     *
     * @param customerId Id of the Customer
     * @param subscriptionId Id of the subscription, which is unique for a customer
     * @return the request
     */
    public Get get(java.lang.String customerId, java.lang.String subscriptionId) throws java.io.IOException {
      Get result = new Get(customerId, subscriptionId);
      initialize(result);
      return result;
    }

    public class Get extends ResellerRequest<com.google.api.services.reseller.model.Subscription> {

      private static final String REST_PATH = "customers/{customerId}/subscriptions/{subscriptionId}";

      /**
       * Gets a subscription of the customer.
       *
       * Create a request for the method "subscriptions.get".
       *
       * This request holds the parameters needed by the the reseller server.  After setting any
       * optional parameters, call the {@link Get#execute()} method to invoke the remote operation. <p>
       * {@link Get#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param customerId Id of the Customer
       * @param subscriptionId Id of the subscription, which is unique for a customer
       * @since 1.13
       */
      protected Get(java.lang.String customerId, java.lang.String subscriptionId) {
        super(Reseller.this, "GET", REST_PATH, null, com.google.api.services.reseller.model.Subscription.class);
        this.customerId = com.google.api.client.util.Preconditions.checkNotNull(customerId, "Required parameter customerId must be specified.");
        this.subscriptionId = com.google.api.client.util.Preconditions.checkNotNull(subscriptionId, "Required parameter subscriptionId must be specified.");
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public Get setAlt(java.lang.String alt) {
        return (Get) super.setAlt(alt);
      }

      @Override
      public Get setFields(java.lang.String fields) {
        return (Get) super.setFields(fields);
      }

      @Override
      public Get setKey(java.lang.String key) {
        return (Get) super.setKey(key);
      }

      @Override
      public Get setOauthToken(java.lang.String oauthToken) {
        return (Get) super.setOauthToken(oauthToken);
      }

      @Override
      public Get setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Get) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Get setQuotaUser(java.lang.String quotaUser) {
        return (Get) super.setQuotaUser(quotaUser);
      }

      @Override
      public Get setUserIp(java.lang.String userIp) {
        return (Get) super.setUserIp(userIp);
      }

      /** Id of the Customer */
      @com.google.api.client.util.Key
      private java.lang.String customerId;

      /** Id of the Customer
       */
      public java.lang.String getCustomerId() {
        return customerId;
      }

      /** Id of the Customer */
      public Get setCustomerId(java.lang.String customerId) {
        this.customerId = customerId;
        return this;
      }

      /** Id of the subscription, which is unique for a customer */
      @com.google.api.client.util.Key
      private java.lang.String subscriptionId;

      /** Id of the subscription, which is unique for a customer
       */
      public java.lang.String getSubscriptionId() {
        return subscriptionId;
      }

      /** Id of the subscription, which is unique for a customer */
      public Get setSubscriptionId(java.lang.String subscriptionId) {
        this.subscriptionId = subscriptionId;
        return this;
      }

      @Override
      public Get set(String parameterName, Object value) {
        return (Get) super.set(parameterName, value);
      }
    }
    /**
     * Creates/Transfers a subscription for the customer.
     *
     * Create a request for the method "subscriptions.insert".
     *
     * This request holds the parameters needed by the the reseller server.  After setting any optional
     * parameters, call the {@link Insert#execute()} method to invoke the remote operation.
     *
     * @param customerId Id of the Customer
     * @param content the {@link com.google.api.services.reseller.model.Subscription}
     * @return the request
     */
    public Insert insert(java.lang.String customerId, com.google.api.services.reseller.model.Subscription content) throws java.io.IOException {
      Insert result = new Insert(customerId, content);
      initialize(result);
      return result;
    }

    public class Insert extends ResellerRequest<com.google.api.services.reseller.model.Subscription> {

      private static final String REST_PATH = "customers/{customerId}/subscriptions";

      /**
       * Creates/Transfers a subscription for the customer.
       *
       * Create a request for the method "subscriptions.insert".
       *
       * This request holds the parameters needed by the the reseller server.  After setting any
       * optional parameters, call the {@link Insert#execute()} method to invoke the remote operation.
       * <p> {@link
       * Insert#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)} must
       * be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @param customerId Id of the Customer
       * @param content the {@link com.google.api.services.reseller.model.Subscription}
       * @since 1.13
       */
      protected Insert(java.lang.String customerId, com.google.api.services.reseller.model.Subscription content) {
        super(Reseller.this, "POST", REST_PATH, content, com.google.api.services.reseller.model.Subscription.class);
        this.customerId = com.google.api.client.util.Preconditions.checkNotNull(customerId, "Required parameter customerId must be specified.");
      }

      @Override
      public Insert setAlt(java.lang.String alt) {
        return (Insert) super.setAlt(alt);
      }

      @Override
      public Insert setFields(java.lang.String fields) {
        return (Insert) super.setFields(fields);
      }

      @Override
      public Insert setKey(java.lang.String key) {
        return (Insert) super.setKey(key);
      }

      @Override
      public Insert setOauthToken(java.lang.String oauthToken) {
        return (Insert) super.setOauthToken(oauthToken);
      }

      @Override
      public Insert setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (Insert) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public Insert setQuotaUser(java.lang.String quotaUser) {
        return (Insert) super.setQuotaUser(quotaUser);
      }

      @Override
      public Insert setUserIp(java.lang.String userIp) {
        return (Insert) super.setUserIp(userIp);
      }

      /** Id of the Customer */
      @com.google.api.client.util.Key
      private java.lang.String customerId;

      /** Id of the Customer
       */
      public java.lang.String getCustomerId() {
        return customerId;
      }

      /** Id of the Customer */
      public Insert setCustomerId(java.lang.String customerId) {
        this.customerId = customerId;
        return this;
      }

      /**
       * An auth token needed for transferring a subscription. Can be generated at
       * https://www.google.com/a/cpanel/customer-domain/TransferToken. Optional.
       */
      @com.google.api.client.util.Key
      private java.lang.String customerAuthToken;

      /** An auth token needed for transferring a subscription. Can be generated at
     https://www.google.com/a/cpanel/customer-domain/TransferToken. Optional.
       */
      public java.lang.String getCustomerAuthToken() {
        return customerAuthToken;
      }

      /**
       * An auth token needed for transferring a subscription. Can be generated at
       * https://www.google.com/a/cpanel/customer-domain/TransferToken. Optional.
       */
      public Insert setCustomerAuthToken(java.lang.String customerAuthToken) {
        this.customerAuthToken = customerAuthToken;
        return this;
      }

      @Override
      public Insert set(String parameterName, Object value) {
        return (Insert) super.set(parameterName, value);
      }
    }
    /**
     * Lists subscriptions of a reseller, optionally filtered by a customer name prefix.
     *
     * Create a request for the method "subscriptions.list".
     *
     * This request holds the parameters needed by the the reseller server.  After setting any optional
     * parameters, call the {@link List#execute()} method to invoke the remote operation.
     *
     * @return the request
     */
    public List list() throws java.io.IOException {
      List result = new List();
      initialize(result);
      return result;
    }

    public class List extends ResellerRequest<com.google.api.services.reseller.model.Subscriptions> {

      private static final String REST_PATH = "subscriptions";

      /**
       * Lists subscriptions of a reseller, optionally filtered by a customer name prefix.
       *
       * Create a request for the method "subscriptions.list".
       *
       * This request holds the parameters needed by the the reseller server.  After setting any
       * optional parameters, call the {@link List#execute()} method to invoke the remote operation. <p>
       * {@link List#initialize(com.google.api.client.googleapis.services.AbstractGoogleClientRequest)}
       * must be called to initialize this instance immediately after invoking the constructor. </p>
       *
       * @since 1.13
       */
      protected List() {
        super(Reseller.this, "GET", REST_PATH, null, com.google.api.services.reseller.model.Subscriptions.class);
      }

      @Override
      public com.google.api.client.http.HttpResponse executeUsingHead() throws java.io.IOException {
        return super.executeUsingHead();
      }

      @Override
      public com.google.api.client.http.HttpRequest buildHttpRequestUsingHead() throws java.io.IOException {
        return super.buildHttpRequestUsingHead();
      }

      @Override
      public List setAlt(java.lang.String alt) {
        return (List) super.setAlt(alt);
      }

      @Override
      public List setFields(java.lang.String fields) {
        return (List) super.setFields(fields);
      }

      @Override
      public List setKey(java.lang.String key) {
        return (List) super.setKey(key);
      }

      @Override
      public List setOauthToken(java.lang.String oauthToken) {
        return (List) super.setOauthToken(oauthToken);
      }

      @Override
      public List setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (List) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public List setQuotaUser(java.lang.String quotaUser) {
        return (List) super.setQuotaUser(quotaUser);
      }

      @Override
      public List setUserIp(java.lang.String userIp) {
        return (List) super.setUserIp(userIp);
      }

      /** Token to specify next page in the list */
      @com.google.api.client.util.Key
      private java.lang.String pageToken;

      /** Token to specify next page in the list
       */
      public java.lang.String getPageToken() {
        return pageToken;
      }

      /** Token to specify next page in the list */
      public List setPageToken(java.lang.String pageToken) {
        this.pageToken = pageToken;
        return this;
      }

      /** Maximum number of results to return */
      @com.google.api.client.util.Key
      private java.lang.Long maxResults;

      /** Maximum number of results to return

     [minimum: 1] [maximum: 100]
       */
      public java.lang.Long getMaxResults() {
        return maxResults;
      }

      /** Maximum number of results to return */
      public List setMaxResults(java.lang.Long maxResults) {
        this.maxResults = maxResults;
        return this;
      }

      /**
       * Prefix of the customer's domain name by which the subscriptions should be filtered.
       * Optional
       */
      @com.google.api.client.util.Key
      private java.lang.String customerNamePrefix;

      /** Prefix of the customer's domain name by which the subscriptions should be filtered. Optional
       */
      public java.lang.String getCustomerNamePrefix() {
        return customerNamePrefix;
      }

      /**
       * Prefix of the customer's domain name by which the subscriptions should be filtered.
       * Optional
       */
      public List setCustomerNamePrefix(java.lang.String customerNamePrefix) {
        this.customerNamePrefix = customerNamePrefix;
        return this;
      }

      @Override
      public List set(String parameterName, Object value) {
        return (List) super.set(parameterName, value);
      }
    }
    /**
     * Starts paid service of a trial subscription
     *
     * Create a request for the method "subscriptions.startPaidService".
     *
     * This request holds the parameters needed by the the reseller server.  After setting any optional
     * parameters, call the {@link StartPaidService#execute()} method to invoke the remote operation.
     *
     * @param customerId Id of the Customer
     * @param subscriptionId Id of the subscription, which is unique for a customer
     * @return the request
     */
    public StartPaidService startPaidService(java.lang.String customerId, java.lang.String subscriptionId) throws java.io.IOException {
      StartPaidService result = new StartPaidService(customerId, subscriptionId);
      initialize(result);
      return result;
    }

    public class StartPaidService extends ResellerRequest<com.google.api.services.reseller.model.Subscription> {

      private static final String REST_PATH = "customers/{customerId}/subscriptions/{subscriptionId}/startPaidService";

      /**
       * Starts paid service of a trial subscription
       *
       * Create a request for the method "subscriptions.startPaidService".
       *
       * This request holds the parameters needed by the the reseller server.  After setting any
       * optional parameters, call the {@link StartPaidService#execute()} method to invoke the remote
       * operation. <p> {@link StartPaidService#initialize(com.google.api.client.googleapis.services.Abs
       * tractGoogleClientRequest)} must be called to initialize this instance immediately after
       * invoking the constructor. </p>
       *
       * @param customerId Id of the Customer
       * @param subscriptionId Id of the subscription, which is unique for a customer
       * @since 1.13
       */
      protected StartPaidService(java.lang.String customerId, java.lang.String subscriptionId) {
        super(Reseller.this, "POST", REST_PATH, null, com.google.api.services.reseller.model.Subscription.class);
        this.customerId = com.google.api.client.util.Preconditions.checkNotNull(customerId, "Required parameter customerId must be specified.");
        this.subscriptionId = com.google.api.client.util.Preconditions.checkNotNull(subscriptionId, "Required parameter subscriptionId must be specified.");
      }

      @Override
      public StartPaidService setAlt(java.lang.String alt) {
        return (StartPaidService) super.setAlt(alt);
      }

      @Override
      public StartPaidService setFields(java.lang.String fields) {
        return (StartPaidService) super.setFields(fields);
      }

      @Override
      public StartPaidService setKey(java.lang.String key) {
        return (StartPaidService) super.setKey(key);
      }

      @Override
      public StartPaidService setOauthToken(java.lang.String oauthToken) {
        return (StartPaidService) super.setOauthToken(oauthToken);
      }

      @Override
      public StartPaidService setPrettyPrint(java.lang.Boolean prettyPrint) {
        return (StartPaidService) super.setPrettyPrint(prettyPrint);
      }

      @Override
      public StartPaidService setQuotaUser(java.lang.String quotaUser) {
        return (StartPaidService) super.setQuotaUser(quotaUser);
      }

      @Override
      public StartPaidService setUserIp(java.lang.String userIp) {
        return (StartPaidService) super.setUserIp(userIp);
      }

      /** Id of the Customer */
      @com.google.api.client.util.Key
      private java.lang.String customerId;

      /** Id of the Customer
       */
      public java.lang.String getCustomerId() {
        return customerId;
      }

      /** Id of the Customer */
      public StartPaidService setCustomerId(java.lang.String customerId) {
        this.customerId = customerId;
        return this;
      }

      /** Id of the subscription, which is unique for a customer */
      @com.google.api.client.util.Key
      private java.lang.String subscriptionId;

      /** Id of the subscription, which is unique for a customer
       */
      public java.lang.String getSubscriptionId() {
        return subscriptionId;
      }

      /** Id of the subscription, which is unique for a customer */
      public StartPaidService setSubscriptionId(java.lang.String subscriptionId) {
        this.subscriptionId = subscriptionId;
        return this;
      }

      @Override
      public StartPaidService set(String parameterName, Object value) {
        return (StartPaidService) super.set(parameterName, value);
      }
    }

  }

  /**
   * Builder for {@link Reseller}.
   *
   * <p>
   * Implementation is not thread-safe.
   * </p>
   *
   * @since 1.3.0
   */
  public static final class Builder extends com.google.api.client.googleapis.services.json.AbstractGoogleJsonClient.Builder {

    /**
     * Returns an instance of a new builder.
     *
     * @param transport HTTP transport, which should normally be:
     *        <ul>
     *        <li>Google App Engine:
     *        {@code com.google.api.client.extensions.appengine.http.UrlFetchTransport}</li>
     *        <li>Android: {@code newCompatibleTransport} from
     *        {@code com.google.api.client.extensions.android.http.AndroidHttp}</li>
     *        <li>Java: {@link com.google.api.client.googleapis.javanet.GoogleNetHttpTransport#newTrustedTransport()}
     *        </li>
     *        </ul>
     * @param jsonFactory JSON factory, which may be:
     *        <ul>
     *        <li>Jackson: {@code com.google.api.client.json.jackson2.JacksonFactory}</li>
     *        <li>Google GSON: {@code com.google.api.client.json.gson.GsonFactory}</li>
     *        <li>Android Honeycomb or higher:
     *        {@code com.google.api.client.extensions.android.json.AndroidJsonFactory}</li>
     *        </ul>
     * @param httpRequestInitializer HTTP request initializer or {@code null} for none
     * @since 1.7
     */
    public Builder(com.google.api.client.http.HttpTransport transport, com.google.api.client.json.JsonFactory jsonFactory,
        com.google.api.client.http.HttpRequestInitializer httpRequestInitializer) {
      super(
          transport,
          jsonFactory,
          DEFAULT_ROOT_URL,
          DEFAULT_SERVICE_PATH,
          httpRequestInitializer,
          false);
    }

    /** Builds a new instance of {@link Reseller}. */
    @Override
    public Reseller build() {
      return new Reseller(this);
    }

    @Override
    public Builder setRootUrl(String rootUrl) {
      return (Builder) super.setRootUrl(rootUrl);
    }

    @Override
    public Builder setServicePath(String servicePath) {
      return (Builder) super.setServicePath(servicePath);
    }

    @Override
    public Builder setHttpRequestInitializer(com.google.api.client.http.HttpRequestInitializer httpRequestInitializer) {
      return (Builder) super.setHttpRequestInitializer(httpRequestInitializer);
    }

    @Override
    public Builder setApplicationName(String applicationName) {
      return (Builder) super.setApplicationName(applicationName);
    }

    @Override
    public Builder setSuppressPatternChecks(boolean suppressPatternChecks) {
      return (Builder) super.setSuppressPatternChecks(suppressPatternChecks);
    }

    @Override
    public Builder setSuppressRequiredParameterChecks(boolean suppressRequiredParameterChecks) {
      return (Builder) super.setSuppressRequiredParameterChecks(suppressRequiredParameterChecks);
    }

    @Override
    public Builder setSuppressAllChecks(boolean suppressAllChecks) {
      return (Builder) super.setSuppressAllChecks(suppressAllChecks);
    }

    /**
     * Set the {@link ResellerRequestInitializer}.
     *
     * @since 1.12
     */
    public Builder setResellerRequestInitializer(
        ResellerRequestInitializer resellerRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(resellerRequestInitializer);
    }

    @Override
    public Builder setGoogleClientRequestInitializer(
        com.google.api.client.googleapis.services.GoogleClientRequestInitializer googleClientRequestInitializer) {
      return (Builder) super.setGoogleClientRequestInitializer(googleClientRequestInitializer);
    }
  }
}
